pub struct TransferCheckedGlobalOnlyReward<'info> {
pub buddy_link_program: AccountInfo<'info>,
pub authority: AccountInfo<'info>,
pub system_program: Option<AccountInfo<'info>>,
pub mint: Option<AccountInfo<'info>>,
pub token_program: Option<AccountInfo<'info>>,
pub from_token_account: Option<AccountInfo<'info>>,
pub referrer_token_account: Option<AccountInfo<'info>>,
pub global_referrer_treasury: AccountInfo<'info>,
pub global_referrer_treasury_for_reward: AccountInfo<'info>,
pub referee_buddy_profile: AccountInfo<'info>,
pub referee_buddy: AccountInfo<'info>,
}Fields
buddy_link_program: AccountInfo<'info>CHECK: The buddylink program
CHECK: Authority of the account sending the funds.
system_program: Option<AccountInfo<'info>>CHECK: System Program - Only used if sending SOL, None if sending SPL.
mint: Option<AccountInfo<'info>>CHECK: Mint, None if sending SOL.
token_program: Option<AccountInfo<'info>>CHECK: Token program, None if sending SOL.
from_token_account: Option<AccountInfo<'info>>CHECK: From token account - None if sending SOL (will send from authority), else is Token Account
referrer_token_account: Option<AccountInfo<'info>>CHECK: Referrer token account - None if receiving SOL (will send to treasury), else is Token Account
global_referrer_treasury: AccountInfo<'info>CHECK: Global referrer treasury (treasury of the global referrer of current referee).
global_referrer_treasury_for_reward: AccountInfo<'info>CHECK: Global referrer treasury for reward (treasury of the global referrer of current referee that is linked to the current mint, could be same as ).
referee_buddy_profile: AccountInfo<'info>CHECK: Buddy Link Profile of the referee.
referee_buddy: AccountInfo<'info>CHECK: Buddy Link Paid buddy of the referee (could be the same as above).