pub struct TransferCheckedGlobalReward<'info> {
pub buddy_link_program: AccountInfo<'info>,
pub authority: AccountInfo<'info>,
pub mint: AccountInfo<'info>,
pub token_program: AccountInfo<'info>,
pub from_token_account: AccountInfo<'info>,
pub referrer_token_account: AccountInfo<'info>,
pub referrer_member: Option<AccountInfo<'info>>,
pub referrer_treasury: AccountInfo<'info>,
pub referrer_treasury_for_reward: AccountInfo<'info>,
pub referee_member: AccountInfo<'info>,
pub buddy_global_referrer_treasury: Option<AccountInfo<'info>>,
pub buddy_global_referrer_token_account: Option<AccountInfo<'info>>,
}Fields
buddy_link_program: AccountInfo<'info>CHECK: The buddylink program
CHECK: Authority of the account sending the funds.
mint: AccountInfo<'info>CHECK: Mint
token_program: AccountInfo<'info>CHECK: Token program
from_token_account: AccountInfo<'info>CHECK: Account sending the funds.
referrer_token_account: AccountInfo<'info>CHECK: Account receiving the funds (buddy link owned).
referrer_member: Option<AccountInfo<'info>>CHECK: Referrer member (account of the referrer within your organization) (None if don’t want on-chain analytics).
referrer_treasury: AccountInfo<'info>CHECK: Referrer treasury (treasury that owns the referrer member ).
referrer_treasury_for_reward: AccountInfo<'info>CHECK: Referrer treasury for reward (treasury that is linked to the current mint, could be the same as above).
referee_member: AccountInfo<'info>CHECK: Referee member (account of the referee within your organization).
buddy_global_referrer_treasury: Option<AccountInfo<'info>>CHECK: Global referrer treasury (treasury of the global referrer of current referee) (None if user doesn’t have global referrer).
buddy_global_referrer_token_account: Option<AccountInfo<'info>>CHECK: Global referrer token account linked to the above account.