pub struct ValidateReferrer<'info> {
pub buddy_link_program: AccountInfo<'info>,
pub payer: AccountInfo<'info>,
pub authority: AccountInfo<'info>,
pub referee_buddy_profile: AccountInfo<'info>,
pub referee_buddy: AccountInfo<'info>,
pub referee_treasury: AccountInfo<'info>,
pub referee_member: AccountInfo<'info>,
pub referrer_member: Option<AccountInfo<'info>>,
pub referrer_treasury: Option<AccountInfo<'info>>,
pub referrer_treasury_for_reward: Option<AccountInfo<'info>>,
pub referrer_token_account: Option<AccountInfo<'info>>,
pub mint: Option<AccountInfo<'info>>,
}Fields
buddy_link_program: AccountInfo<'info>CHECK: The buddylink program
payer: AccountInfo<'info>CHECK: Payer of the transaction
CHECK: Authority
referee_buddy_profile: AccountInfo<'info>CHECK: Buddy Link Profile of the referee.
referee_buddy: AccountInfo<'info>CHECK: Buddy Link Paid buddy of the referee (could be the same as above).
referee_treasury: AccountInfo<'info>CHECK: Referee treasury (is owned by above).
referee_member: AccountInfo<'info>CHECK: Referee member (account of the referee within your organization).
referrer_member: Option<AccountInfo<'info>>CHECK: Referrer member (account of the referrer within your organization) (if you want to validate the referrer of the current referee).
referrer_treasury: Option<AccountInfo<'info>>CHECK: Referrer treasury (treasury that owns the referrer member ) (if you want to validate the referrer of the current referee).
referrer_treasury_for_reward: Option<AccountInfo<'info>>CHECK: Referrer treasury for reward (treasury that is linked to the current mint, could be the same as above) (if you want to validate the referrer of the current referee).
referrer_token_account: Option<AccountInfo<'info>>CHECK: Token account linked to the mint (if you want to validate the referral tree with a specific mint)
mint: Option<AccountInfo<'info>>CHECK: The mint